@@ -14,6 +14,10 @@ from torweb.config import Yaml_Config
 #from torweb.handlers import StaticFileHandler, ErrorHandler, WSGIRequest
 from torweb.handlers import StaticFileHandler, ErrorHandler
 from code import interact
+from os.path import abspath, dirname, join
+base_path = abspath(dirname(__file__))
+import sys
+sys.path.insert(0, abspath(join(base_path, 'utils')))
 
 def get_modules(prefix, parent):
     if not os.path.isfile(os.path.join(parent, '__init__.py')):
