@@ -80,9 +80,9 @@ class Yaml_Config(object):
     def init_store(self):
         from storm.locals import create_database
         from torweb.db import CacheStore
-        #from torweb.db import CacheQuery
-        #from sqlalchemy import create_engine, MetaData
-        #from sqlalchemy.orm import scoped_session, sessionmaker
+        from torweb.db import CacheQuery
+        from sqlalchemy import create_engine, MetaData
+        from sqlalchemy.orm import scoped_session, sessionmaker
         schemes = self.settings.get('schemes', {})
         for scheme in schemes:
             #if not hasattr(self.app, scheme.get('storm')):
@@ -106,24 +106,29 @@ class Yaml_Config(object):
             cache_store = CacheStore(database)
             setattr(self, scheme.get('storm', 'store'), cache_store)
             setattr(self.app, scheme.get('storm', 'store'), cache_store)
-            #if scheme.get('sqlalchemy', '') != '':
-            #    if key == 'sqlite':
-            #        connection = '%(scheme)s://%(database_name)s'\
-            #            % {'scheme': key,
-            #               'database_name': os.path.join(self.base_path, scheme.get('db', ''))
-            #              }
-            #    engine = create_engine(
-            #        connection,
-            #        convert_unicode=True,
-            #        encoding="utf-8",
-            #        pool_recycle=3600*7,
-            #        #echo_pool=True,
-            #        echo=False,
-            #    )
-            #    metadata = MetaData(bind=engine)
-            #    session = scoped_session(sessionmaker(bind=engine, query_cls=CacheQuery))
-            #    sqlalchemy_sessions = [session]
-            #    DB_Session = sessionmaker(bind=engine)
-            #    setattr(self.app, 'metadata', metadata)
-            #    setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
-            #    setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
+            if scheme.get('sqlalchemy', '') != '':
+                import _mysql_exceptions
+                from sqlalchemy import event
+                from sqlalchemy.exc import DisconnectionError
+                def my_on_checkout(dbapi_conn, connection_rec, connection_proxy):
+                    try:
+                        dbapi_conn.cursor().execute('select now()')
+                    except _mysql_exceptions.OperationalError:
+                        raise DisconnectionError
+                
+                engine = create_engine(
+                    connection,
+                    convert_unicode=True,
+                    encoding="utf-8",
+                    pool_recycle=3600*7,
+                    #echo_pool=True,
+                    echo=False,
+                )
+                event.listen(engine, 'checkout', my_on_checkout)
+                metadata = MetaData(bind=engine)
+                session = scoped_session(sessionmaker(bind=engine, query_cls=CacheQuery))
+                sqlalchemy_sessions = [session]
+                DB_Session = sessionmaker(bind=engine)
+                setattr(self.app, 'metadata', metadata)
+                setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
+                setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
